@@ -347,133 +347,30 @@ plot(upr, position=c(2/3, 0, 1, 1), more=FALSE)
 
 
 ###################################################
-### code chunk number 36: meuse-zinc-block-Kriging
-###################################################
-data(meuse.blocks, package="constrainedKriging")
-str(meuse.blocks, max=2)
-
-
-###################################################
-### code chunk number 37: meuse-zinc-meuse-block-Kriging-1a (eval = FALSE)
-###################################################
-## r.bk <- predict(r.georob.m1.spher.reml, newdata=meuse.blocks,
-##   control=control.predict.georob(extended.output=TRUE, pwidth=25, pheight=25, mmax=25))
-
-
-###################################################
-### code chunk number 38: meuse-zinc-meuse-block-Kriging-1b (eval = FALSE)
-###################################################
-## r.bk <- predict(r.georob.m1.spher.reml, newdata=meuse.blocks,
-##   control=control.predict.georob(extended.output=TRUE, pwidth=25, pheight=25))
-
-
-###################################################
-### code chunk number 39: meuse-zinc-meuse-block-Kriging-2 (eval = FALSE)
-###################################################
-## r.bk <- lgnpp(r.bk, newdata=meuse.grid)
-
-
-###################################################
-### code chunk number 40: meuse-zinc-block-Kriging-plot
-###################################################
-getOption("SweaveHooks")[["fig"]]()
-brks <- c(25, 50, 75, 100, 150, 200, seq(500, 3500,by=500))
-pred <- spplot(r.bk, zcol="lgn.pred", at=brks, main="prediction")
-lwr <- spplot(r.bk, zcol="lgn.lower", at=brks, main="lower bound 95% PI")
-upr <- spplot(r.bk, zcol="lgn.upper", at=brks, main="upper bound 95% PI")
-plot(pred, position=c(0, 0, 1/3, 1), more=TRUE)
-plot(lwr, position=c(1/3, 0, 2/3, 1), more=TRUE)
-plot(upr, position=c(2/3, 0, 1, 1), more=FALSE)
-
-
-###################################################
-### code chunk number 41: meuse-zinc-block-Kriging-blocks
-###################################################
-getOption("SweaveHooks")[["fig"]]()
-## define blocks
-tmp <- data.frame(x=c(179100, 179900), y=c(330200, 331000))
-blks <- SpatialPolygons(
-  sapply(1:nrow(tmp), function(i, x){
-  Polygons(list(Polygon(
-    t(x[,i] + 400*t(cbind(c(-1, 1, 1, -1, -1), c(-1, -1, 1, 1, -1)))),
-    hole=FALSE)), ID=paste("block", i, sep="")
-  )}, x=t(tmp)))
-## compute spatial mean of sqrt(dist) for blocks
-ind <- over(as(meuse.grid, "SpatialPoints"), blks)
-tmp <- tapply(sqrt(meuse.grid$dist), ind, mean)
-names(tmp) <- paste("block", 1:length(tmp), sep="")
-## create SpatialPolygonsDataFrame
-blks <- SpatialPolygonsDataFrame(blks, data=data.frame(dist=tmp^2))
-## and plot
-plot(as(meuse.grid, "SpatialPoints"), axes=TRUE)
-plot(geometry(blks), add=TRUE, col=2)
-
-
-###################################################
-### code chunk number 42: meuse-zinc-block-Kriging-3 (eval = FALSE)
-###################################################
-## r.blks <- predict(r.georob.m1.spher.reml, newdata=blks,
-##   control=control.predict.georob(extended.output=TRUE, pwidth=800, pheight=800))
-## r.blks <- lgnpp(r.blks, newdata=meuse.grid)
-
-
-###################################################
-### code chunk number 43: <meuse-zinc-block-Kriging-4a (eval = FALSE)
-###################################################
-## t.pk <- predict(r.georob.m0.spher.reml, newdata=as.data.frame(meuse.grid),
-##   control=control.predict.georob(extended.output=TRUE, full.covmat=TRUE))
-## str(t.pk)
-
-
-###################################################
-### code chunk number 44: meuse-zinc-block-Kriging-5 (eval = FALSE)
-###################################################
-## ## index defining to which block the points predictions belong
-## ind <- over(geometry(meuse.grid), geometry(blks))
-## ind <- tapply(1:nrow(meuse.grid), factor(ind), function(x) x)
-## ## select point predictions in block and predict block average
-## tmp <- t(sapply(ind, function(i, x){
-##   x$pred <- x$pred[i,]
-##   x$mse.pred <- x$mse.pred[i,i]
-##   x$var.pred <- x$var.pred[i,i]
-##   x$cov.pred.target <- x$cov.pred.target[i,i]
-##   x$var.target <- x$var.target[i,i]
-##   res <- lgnpp(x, is.block=TRUE)
-##   res
-##   }, x=t.pk))
-## colnames(tmp) <- c("opt.pred", "opt.se")
-## r.blks <- cbind( r.blks, tmp)
-
-
-###################################################
-### code chunk number 45: meuse-zinc-block-Kriging-6
-###################################################
-r.blks@data[, c("lgn.pred", "opt.pred", "lgn.se", "opt.se")]
-
-
-###################################################
-### code chunk number 46: meuse-zinc-cleanup-1
+### code chunk number 36: meuse-zinc-cleanup-1
 ###################################################
 palette("default")
 
 
 ###################################################
-### code chunk number 47: meuse-zinc-cleanup-2 (eval = FALSE)
+### code chunk number 37: meuse-zinc-cleanup-2 (eval = FALSE)
 ###################################################
 ## # save(list=ls(pattern="^r\\."), file="r_meuse_zinc_objects.RData", version = 2)
 ## save(list=c("r.sv", "r.sv.spher", "r.prfl.m0.spher.reml.scale", "r.cv.m0.spher.reml",
-##     "r.cv.m1.spher.reml", "r.bk", "r.blks"), file="r_meuse_zinc_objects.RData", version = 2)
+##     "r.cv.m1.spher.reml" 
+## #    , "r.bk", "r.blks"
+##   ), file="r_meuse_zinc_objects.RData", version = 2)
 ## rm(list=ls(pattern="^r\\."))
 
 
 ###################################################
-### code chunk number 48: ash-load
+### code chunk number 38: ash-load
 ###################################################
 if(file.exists("r_coalash_objects.RData")) load("r_coalash_objects.RData")
 
 
 ###################################################
-### code chunk number 49: ash-data
+### code chunk number 39: ash-data
 ###################################################
 if(requireNamespace("gstat", quietly = TRUE)){
   data(coalash, package="gstat")
@@ -486,7 +383,7 @@ if(requireNamespace("gstat", quietly = TRUE)){
 
 
 ###################################################
-### code chunk number 50: ash-centred-bubbleplot1
+### code chunk number 40: ash-centred-bubbleplot1
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(y~x, coalash, cex=sqrt(abs(coalash - median(coalash))),
@@ -497,7 +394,7 @@ legend("topleft", pch=1, col=c("blue", "red"), legend=c("< 0", "> 0"), bty="n")
 
 
 ###################################################
-### code chunk number 51: ash-coords-scatterplot
+### code chunk number 41: ash-coords-scatterplot
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(1,2))
@@ -507,14 +404,14 @@ par(op)
 
 
 ###################################################
-### code chunk number 52: ash-centerd-qqnorm
+### code chunk number 42: ash-centerd-qqnorm
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 qqnorm(coalash$coalash)
 
 
 ###################################################
-### code chunk number 53: ash-lmrob
+### code chunk number 43: ash-lmrob
 ###################################################
 library(robustbase)
 r.lmrob <- lmrob(coalash~x+y, coalash)
@@ -522,7 +419,7 @@ summary(r.lmrob)
 
 
 ###################################################
-### code chunk number 54: ash-diag-lmrob
+### code chunk number 44: ash-diag-lmrob
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(2,2))
@@ -531,7 +428,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 55: ash-sv-res-lmrob-iso
+### code chunk number 45: ash-sv-res-lmrob-iso
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 library(georob)
@@ -550,7 +447,7 @@ legend("bottomright", pch=1:4, col=c("black", "blue", "cyan", "orange"),
 
 
 ###################################################
-### code chunk number 56: ash-sv-res-lmrob-aniso
+### code chunk number 46: ash-sv-res-lmrob-aniso
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 r.sv <- sample.variogram(residuals(r.lmrob), locations=coalash[, c("x","y")],
@@ -565,45 +462,45 @@ legend("bottomright", pch=c(1, 3), col=c("blue", "orange"),
 
 
 ###################################################
-### code chunk number 57: ash-georob-robust-1
+### code chunk number 47: ash-georob-robust-1
 ###################################################
 r.georob.m0.exp.c2 <- georob(coalash~x+y, coalash, locations=~x+y,
   variogram.model="RMexp", param=c(variance=0.1, nugget=0.9, scale=1))
 
 
 ###################################################
-### code chunk number 58: ash-summary-georob-robust-1
+### code chunk number 48: ash-summary-georob-robust-1
 ###################################################
 summary(r.georob.m0.exp.c2)
 
 
 ###################################################
-### code chunk number 59: ash-waldtest-quadratic-robust
+### code chunk number 49: ash-waldtest-quadratic-robust
 ###################################################
 waldtest(update(r.georob.m0.exp.c2, .~.+I(x^2)+I(y^2)+I(x*y)), r.georob.m0.exp.c2)
 
 
 ###################################################
-### code chunk number 60: ash-georob-robust-2
+### code chunk number 50: ash-georob-robust-2
 ###################################################
 r.georob.m1.exp.c2 <- update(r.georob.m0.exp.c2, .~.-y)
 
 
 ###################################################
-### code chunk number 61: ash-summary-georob-robust-2
+### code chunk number 51: ash-summary-georob-robust-2
 ###################################################
 r.georob.m1.exp.c2
 
 
 ###################################################
-### code chunk number 62: ash-georob-robust-3
+### code chunk number 52: ash-georob-robust-3
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(r.georob.m1.exp.c2, lag.dist.def=1, max.lag=10, estimator="qn", col="blue")
 
 
 ###################################################
-### code chunk number 63: ash-diag-georob-robust-2-1
+### code chunk number 53: ash-diag-georob-robust-2-1
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(2,2))
@@ -615,7 +512,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 64: ash-rw-georob-robust-2-1
+### code chunk number 54: ash-rw-georob-robust-2-1
 ###################################################
 round(cbind(coalash[, c("x", "y")],
   rweights=r.georob.m1.exp.c2[["rweights"]])[c(15, 50, 63, 73, 88, 111, 192),],
@@ -623,7 +520,7 @@ round(cbind(coalash[, c("x", "y")],
 
 
 ###################################################
-### code chunk number 65: ash-rw-georob-robust-2-1
+### code chunk number 55: ash-rw-georob-robust-2-1
 ###################################################
 sel <- r.georob.m1.exp.c2[["rweights"]] <= 0.8 &
   !1:nrow(coalash) %in% c(15, 50, 63, 73, 88, 111, 192)
@@ -633,7 +530,7 @@ round(cbind(coalash[, c("x", "y")],
 
 
 ###################################################
-### code chunk number 66: ash-diag-georob-robust-2-2
+### code chunk number 56: ash-diag-georob-robust-2-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(y~x, coalash, cex=sqrt(abs(residuals(r.georob.m1.exp.c2))),
@@ -644,19 +541,19 @@ legend("topleft", pch=1, col=c("blue", "red"), legend=c("< 0", "> 0"), bty="n")
 
 
 ###################################################
-### code chunk number 67: ash-georob-gaussian-1
+### code chunk number 57: ash-georob-gaussian-1
 ###################################################
 r.georob.m1.exp.c1000 <- update(r.georob.m1.exp.c2, tuning.psi=1000)
 
 
 ###################################################
-### code chunk number 68: ash-georob-summary-gaussian-1
+### code chunk number 58: ash-georob-summary-gaussian-1
 ###################################################
 summary(r.georob.m1.exp.c1000)
 
 
 ###################################################
-### code chunk number 69: ash-georob-gaussian-2
+### code chunk number 59: ash-georob-gaussian-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(r.georob.m1.exp.c1000, lag.dist.def=1, max.lag=10, estimator="matheron")
@@ -669,7 +566,7 @@ legend("bottomright", lt=1, col=c("black","blue", "orange"),
 
 
 ###################################################
-### code chunk number 70: ash-georob-diag-gaussian-robust-2
+### code chunk number 60: ash-georob-diag-gaussian-robust-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(1,2), cex=5/6)
@@ -686,7 +583,7 @@ abline(0, 1, lty="dotted")
 
 
 ###################################################
-### code chunk number 71: ash-cv-georob-gaussian-robust-1 (eval = FALSE)
+### code chunk number 61: ash-cv-georob-gaussian-robust-1 (eval = FALSE)
 ###################################################
 ## r.cv.georob.m1.exp.c2 <- cv(r.georob.m1.exp.c2, seed=1,
 ##   control=control.georob(initial.param=FALSE))
@@ -694,7 +591,7 @@ abline(0, 1, lty="dotted")
 
 
 ###################################################
-### code chunk number 72: ash-cv-georob-gaussian-robust-2 (eval = FALSE)
+### code chunk number 62: ash-cv-georob-gaussian-robust-2 (eval = FALSE)
 ###################################################
 ## r.cv.georob.m1.exp.c2 <- cv(r.georob.m1.exp.c2, seed=1,
 ##   control=control.georob(initial.param=FALSE), ncores=my.ncores)
@@ -702,21 +599,21 @@ abline(0, 1, lty="dotted")
 
 
 ###################################################
-### code chunk number 73: ash-cv-georob-subsets
+### code chunk number 63: ash-cv-georob-subsets
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 plot(y~x, r.cv.georob.m1.exp.c2$pred, asp=1, col=subset, pch=as.integer(subset))
 
 
 ###################################################
-### code chunk number 74: ash-summary-cv-georob-gaussian-robust
+### code chunk number 64: ash-summary-cv-georob-gaussian-robust
 ###################################################
 summary(r.cv.georob.m1.exp.c1000, se=TRUE)
 summary(r.cv.georob.m1.exp.c2, se=TRUE)
 
 
 ###################################################
-### code chunk number 75: ash-diag-cv-georob-gaussian-robust
+### code chunk number 65: ash-diag-cv-georob-gaussian-robust
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 op <- par(mfrow=c(3, 2))
@@ -741,7 +638,7 @@ par(op)
 
 
 ###################################################
-### code chunk number 76: ash-Kriging-grid
+### code chunk number 66: ash-Kriging-grid
 ###################################################
 coalash.grid <- expand.grid(x=seq(-1, 17, by=0.2),
   y=seq( -1, 24, by=0.2))
@@ -752,21 +649,21 @@ str(coalash.grid, max=2)
 
 
 ###################################################
-### code chunk number 77: ash-pKriging-1 (eval = FALSE)
+### code chunk number 67: ash-pKriging-1 (eval = FALSE)
 ###################################################
 ## r.pk.m1.exp.c2 <- predict(r.georob.m1.exp.c2, newdata=coalash.grid)
 ## r.pk.m1.exp.c1000 <- predict(r.georob.m1.exp.c1000, newdata=coalash.grid)
 
 
 ###################################################
-### code chunk number 78: ash-pKriging-2 (eval = FALSE)
+### code chunk number 68: ash-pKriging-2 (eval = FALSE)
 ###################################################
 ## r.pk.m1.exp.c2 <- predict(r.georob.m1.exp.c2, newdata=coalash.grid, control=control.predict.georob(ncores=my.ncores))
 ## r.pk.m1.exp.c1000 <- predict(r.georob.m1.exp.c1000, newdata=coalash.grid, control=control.predict.georob(ncores=my.ncores))
 
 
 ###################################################
-### code chunk number 79: ash-pKriging-plot-robust-gaussian-1
+### code chunk number 69: ash-pKriging-plot-robust-gaussian-1
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 pred.rob <- spplot(r.pk.m1.exp.c2, "pred", at=seq(8, 12, by=0.25),
@@ -784,7 +681,7 @@ plot(se.gauss, pos=c(0.5, 0, 1, 0.5), more=FALSE)
 
 
 ###################################################
-### code chunk number 80: ash-pKriging-plot-robust-gaussian-2
+### code chunk number 70: ash-pKriging-plot-robust-gaussian-2
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 # rel. difference of predictions
@@ -813,81 +710,13 @@ plot(ratio.msep, pos=c(0.5, 0, 1, 1), more=FALSE)
 
 
 ###################################################
-### code chunk number 81: ash-Kriging-polygons
-###################################################
-getOption("SweaveHooks")[["fig"]]()
-tmp <- expand.grid(x = seq(2.5, 16.5, by=4), y=seq(2, 22, by=4))
-rownames(tmp) <- paste("block", rownames(tmp), sep="")
-# create SpatialPolygonsDataFrame
-coalash.polygons <- sapply(1:nrow(tmp), function(i, x){
-  Polygons(list(Polygon(
-        t(x[,i] + t(cbind(c(-2, 2, 2, -2, -2), c(-2, -2, 2, 2, -2)))),
-        hole=FALSE)), ID=paste("block", i, sep=""))},
-  x=t(tmp))
-coalash.polygons <- SpatialPolygonsDataFrame(SpatialPolygons(coalash.polygons),
-  data = tmp)
-summary(coalash.polygons)
-plot(coalash.polygons, col="grey", axes=TRUE); points(y~x, coalash)
-
-
-###################################################
-### code chunk number 82: ash-bKriging-1 (eval = FALSE)
-###################################################
-## r.bk.m1.exp.c2 <- predict(r.georob.m1.exp.c2, newdata=coalash.polygons,
-##   control=control.predict.georob(pwidth=4, pheight=4, full.covmat=TRUE))
-## r.bk.m1.exp.c1000 <- predict(r.georob.m1.exp.c1000, newdata=coalash.polygons,
-##   control=control.predict.georob(pwidth=4, pheight=4, full.covmat=TRUE))
-
-
-###################################################
-### code chunk number 83: ash-str-bKriging
-###################################################
-str(r.bk.m1.exp.c2, max=2)
-
-
-###################################################
-### code chunk number 84: ash-gKriging
-###################################################
-c(pred=mean(r.bk.m1.exp.c2$pred$pred),
-  se=sqrt(sum(r.bk.m1.exp.c2$mse.pred))/24)
-
-
-###################################################
-### code chunk number 85: ash-bKriging-2
-###################################################
-coalash.domain <- rbind(c(0.5,0), c(16.5,0), c(16.5,24), c(0.5,24), c(0.5,0))
-coalash.domain <- SpatialPolygonsDataFrame(
-  SpatialPolygons(list(Polygons(list(Polygon(coalash.domain)), ID= "domain"))),
-  data=data.frame(x=8.5,y=12,row.names="domain"))
-slot(predict(r.georob.m1.exp.c2, newdata=coalash.domain,
-  control=control.predict.georob(pwidth=16, pheight=24)), "data")
-
-
-###################################################
-### code chunk number 86: ash-bKriging-plot-robust-gaussian-1
-###################################################
-getOption("SweaveHooks")[["fig"]]()
-pred.rob <- spplot(r.bk.m1.exp.c2$pred, "pred", at=seq(8, 11, by=0.25),
-  main="robust Kriging prediction", scales=list(draw=TRUE))
-pred.gauss <- spplot(r.bk.m1.exp.c1000$pred, "pred", at=seq(8, 11, by=0.25),
-  main="Gaussian Kriging prediction", scales=list(draw=TRUE))
-se.rob <- spplot(r.bk.m1.exp.c2$pred, "se", at=seq(0.15, 0.45, by=0.025),
-  main="standard error robust Kriging", scales=list(draw=TRUE))
-se.gauss <- spplot(r.bk.m1.exp.c1000$pred, "se", at=seq(0.15, 0.45, by=0.025),
-  main="standard error Gaussian Kriging", scales=list(draw=TRUE))
-plot(pred.rob, pos=c(0, 0.5, 0.5, 1), more=TRUE)
-plot(pred.gauss, pos=c(0.5, 0.5, 1, 1), more=TRUE)
-plot(se.rob, pos=c(0, 0, 0.5, 0.5), more=TRUE)
-plot(se.gauss, pos=c(0.5, 0, 1, 0.5), more=FALSE)
-
-
-###################################################
-### code chunk number 87: ash-results-save-1 (eval = FALSE)
+### code chunk number 71: ash-results-save-1 (eval = FALSE)
 ###################################################
 ## # save(list=ls(pattern="^r\\."), file="r_coalash_objects.RData", version = 2)
 ## save(list=c(
 ##     "r.cv.georob.m1.exp.c2", "r.cv.georob.m1.exp.c1000",
-##     "r.pk.m1.exp.c2", "r.pk.m1.exp.c1000", "r.bk.m1.exp.c2", "r.bk.m1.exp.c1000"
+##     "r.pk.m1.exp.c2", "r.pk.m1.exp.c1000" 
+## #    , "r.bk.m1.exp.c2", "r.bk.m1.exp.c1000"
 ##   ), file="r_coalash_objects.RData", version = 2)
 ## rm(list=ls(pattern="^r\\."))
 
